@@ -714,7 +714,7 @@ class Component(CoordinateBox, Interactor):
             else:
                 x, y = self.position
                 width, height = self.bounds
-            
+
             if not self.draw_valid:
                 if hasattr(GraphicsContext, 'create_from_gc'):
                     # For some backends, such as the mac, a much more efficient
@@ -722,6 +722,22 @@ class Component(CoordinateBox, Interactor):
                     bb = GraphicsContext.create_from_gc(gc, (int(width), int(height)))
                 else:
                     bb = GraphicsContext((int(width), int(height)))
+
+                # if not fill_padding, then we have to fill the backbuffer 
+                # with the window color. This is the only way I've found that
+                # it works- perhaps if we had better blend support we could set
+                # the alpha to 0, but for now doing so causes the backbuffer's
+                # background to be white  
+                if not self.fill_padding:
+                    bb.save_state()
+                    bb.set_antialias(False)
+                    try:
+                        bb.set_fill_color(self.window.bgcolor_)
+                        bb.draw_rect((x, y, width, height), FILL)
+                    finally:
+                        bb.restore_state()
+                   
+                
                 # Fixme: should there be a +1 here?
                 bb.translate_ctm(-x+0.5, -y+0.5)
                 # There are a couple of strategies we could use here, but we
@@ -736,13 +752,14 @@ class Component(CoordinateBox, Interactor):
                 
                 self._backbuffer = bb
                 self.draw_valid = True
-            
+
             # Blit the backbuffer and then draw the overlay on top
             gc.draw_image(self._backbuffer, (x, y, width, height))
             self._dispatch_draw("overlay", gc, view_bounds, mode)
         else:
             for layer in self.draw_order:
                 self._dispatch_draw(layer, gc, view_bounds, mode)
+                
         return
 
     def _dispatch_draw(self, layer, gc, view_bounds, mode):
@@ -807,9 +824,10 @@ class Component(CoordinateBox, Interactor):
         gc.set_stroke_color(self.border_color_)
         gc.begin_path()
         gc.set_antialias(0)
-        gc.rect(int(self.x+border_width/2.0), int(self.y+border_width/2.0),
-                self.width-2*border_width+1, self.height-2*border_width+1)
-
+        gc.rect(int(self.x+border_width/2.0), 
+                  int(self.y+border_width/2.0),
+                  int(self.width-2*border_width+1), 
+                  int(self.height-2*border_width+1))
         gc.stroke_path()
         gc.restore_state()
 
@@ -832,7 +850,6 @@ class Component(CoordinateBox, Interactor):
             try:
                 gc.set_fill_color(self.bgcolor_)
                 gc.draw_rect(r, FILL)
-                
             finally:
                 gc.restore_state()
         
@@ -1095,16 +1112,21 @@ class Component(CoordinateBox, Interactor):
         if new:
             self._layout_needed = True
 
-    #------------------------------------------------------------------------
-    # Position and padding setters and getters
-    #------------------------------------------------------------------------
-
-    def _get_window(self, win):
-        return self._window
+    def _get_window(self):
+        if self._window is not None:
+            return self._window
+        elif self.container is not None:
+            return self.container.window
+        else:
+            return None
 
     def _set_window(self, win):
         self._window = win
 
+    #------------------------------------------------------------------------
+    # Position and padding setters and getters
+    #------------------------------------------------------------------------
+
     def _get_x(self):
         return self.position[0]
 
@@ -1173,7 +1195,7 @@ class Component(CoordinateBox, Interactor):
         return self.x2 + self.padding_right + self._get_visible_border()
 
     def _set_outer_x2(self, val):
-        self.x2 = val - self.hpadding
+        self.x2 = val - self.padding_right - self._get_visible_border()
 
     def _get_outer_y(self):
         return self.y - self.padding_bottom - self._get_visible_border()
@@ -1186,7 +1208,7 @@ class Component(CoordinateBox, Interactor):
         return self.y2 + self.padding_top + self._get_visible_border()
 
     def _set_outer_y2(self, val):
-        self.y2 = val - self.vpadding
+        self.y2 = val - self.padding_top - self._get_visible_border()
 
     #------------------------------------------------------------------------
     # Outer bounds setters and getters
