@@ -1,14 +1,13 @@
 
-from numpy import linspace, zeros, zeros_like
+from numpy import linspace, zeros
 
 # Enthought library imports
 from enthought.kiva import STROKE
-from enthought.traits.api import Any, Bool, Enum, Float, Instance, Int, Property, \
-        on_trait_change, Trait
+from enthought.traits.api import (Any, Bool, Enum, Float, Int, Property,
+                                  on_trait_change, Trait)
 from enthought.traits.ui.api import EnumEditor
 
 # Local, relative imports
-from base_tool import BaseTool
 from colors import ColorTrait
 from component import Component
 from markers import MarkerNameDict, marker_names, CustomMarker
@@ -41,6 +40,8 @@ class Slider(Component):
     # Whether this is a horizontal or vertical slider
     orientation = Enum("h", "v")
 
+    # The thickness, in pixels, of the lines used to render the ticks,
+    # endcaps, and main slider bar.
     bar_width = Int(4)
 
     bar_color = ColorTrait("black")
@@ -423,6 +424,7 @@ class Slider(Component):
     def dragging_mouse_move(self, event):
         dx, dy = self._offset
         self.value = self.map_data(event.x - dx, event.y - dy)
+        event.handled = True
         self.request_redraw()
 
     def dragging_mouse_leave(self, event):
@@ -456,18 +458,20 @@ class Slider(Component):
         elif self.orientation == "h" and (y <= event.y <= y2):
             if not (x <= event.x <= x2):
                 self._offset = (0, event.y - pt[1])
-                self.dragging_mouse_event(event)
+                self.dragging_mouse_move(event)
             else:
                 self._offset = (event.x - pt[0], event.y - pt[1])
         else:
             # The mouse click missed the bar and the slider.
             return
 
+        event.handled = True
         self.event_state = "dragging"
         return
 
     def _mouse_released(self, event):
         self.event_state = "normal"
+        event.handled = True
 
     #------------------------------------------------------------------------
     # Private trait event handlers and property getters/setters
