@@ -9,6 +9,7 @@
 # Thanks for using Enthought open source!
 #
 #------------------------------------------------------------------------------
+
 """ Trait definition for an RGBA-based color, which is either:
 
 * A tuple of the form (*red*,*green*,*blue*,*alpha*), where each component is
@@ -17,20 +18,31 @@
   RR is red, GG is green, and BB is blue.
 """
 
-
+from enthought.etsconfig.api import ETSConfig
+from enthought.enable.traits.ui.api import RGBAColorEditor
 from enthought.traits.api import Trait, TraitError, TraitFactory
 from enthought.traits.trait_base import SequenceTypes
 
-from enthought.etsconfig.api import ETSConfig
-
 if ETSConfig.toolkit == 'wx':
     from enthought.traits.ui.wx.color_trait import standard_colors
+    def rgba_color(color):
+        return ( color.Red() / 255.0,
+                 color.Green() / 255.0,
+                 color.Blue() / 255.0,
+                 1.0 )
 elif ETSConfig.toolkit == 'qt4':
-    # FIXME
-    #from enthought.traits.ui.qt4.color_trait import standard_colors
-    standard_colors = {}
+    from enthought.traits.ui.qt4.color_trait import standard_colors
+    def rgba_color(color):
+        return ( color.red() / 255.0,
+                 color.green() / 255.0,
+                 color.blue() / 255.0,
+                 1.0 )
 else:
     from enthought.traits.ui.null.color_trait import standard_colors
+    def rgba_color(color):
+        return (((color >> 16) & 0xFF) / 255.0,
+                ((color >>  8) & 0xFF) / 255.0,
+                (color & 0xFF)        / 255.0 )
 
 
 #-------------------------------------------------------------------------------
@@ -67,15 +79,9 @@ convert_to_color.info = ('a tuple of the form (red,green,blue,alpha), where '
 
 # RGBA versions of standard colors
 rgba_standard_colors = {}
-try:
-    for name, color in standard_colors.items():
-        rgba_standard_colors[ name ] = ( color.Red()   / 255.0,
-                                         color.Green() / 255.0,
-                                         color.Blue()  / 255.0,
-                                         1.0 )
-    rgba_standard_colors[ 'clear' ] = ( 0, 0, 0, 0 )
-except:
-    pass
+for name, color in standard_colors.items():
+    rgba_standard_colors[ name ] = rgba_color(color)
+rgba_standard_colors[ 'clear' ] = ( 0, 0, 0, 0 )
 
 #-------------------------------------------------------------------------------
 #  Define Enable/Kiva specific color traits:
@@ -100,16 +106,6 @@ def RGBAColorFunc(*args, **metadata):
     -------------
     For wxPython, (1.0, 1.0, 1.0, 1.0) (that is, opaque white)
     """
-    # The editor is commented out for now to avoid a circular import.
-    if ETSConfig.toolkit == 'wx':
-        from enthought.enable.traits.ui.wx.rgba_color_editor import RGBAColorEditor
-    elif ETSConfig.toolkit == 'qt4':
-        # FIXME
-        #from enthought.enable.traits.ui.qt4.rgba_color_editor import RGBAColorEditor
-        RGBAColorEditor = None
-    else:
-        RGBAColorEditor = None
-
     tmp_trait = Trait( 'white', convert_to_color, rgba_standard_colors, 
            editor = RGBAColorEditor )
     return tmp_trait(*args, **metadata)
