@@ -1,6 +1,8 @@
+import warnings
 
 from enthought.tvtk.api import tvtk
-from enthought.traits.api import HasTraits, Any, Property, Instance, \
+from enthought.tvtk import messenger
+from enthought.traits.api import HasTraits, Any, Callable, Property, Instance, \
         Bool, Enum, Int, on_trait_change
 
 from numpy import arange, zeros, ascontiguousarray, reshape, uint8, any
@@ -16,6 +18,19 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
     # from observing the RenderWindowInteractor
     control = Instance(tvtk.RenderWindowInteractor)
 
+    # A callable that will be called to request a render. If this
+    # is None then we will call render on the control. 
+    request_render = Callable
+
+    # If events don't get handled by anything in Enable, do they get passed
+    # through to the underlying VTK InteractorStyle?
+    #
+    # This defaults to False because for opaque objects and backgrounds event
+    # pass-through can be surprising.  However, it can be useful in the cases
+    # when a transparent Enable container or collection of objects overlays
+    # a VTK window.
+    event_passthrough = Bool(False)
+
     #------------------------------------------------------------------------
     # Layout traits
     #------------------------------------------------------------------------
@@ -95,28 +110,24 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
         self.renderer = renderer
         rwi = render_window_interactor
 
-        #if rwi.interactor_style is None:
-        if 1:       
-            rwi.interactor_style = istyle_class()
-        #else:
-        #    print "previous interactor style:", rwi.interactor_style
+        rwi.interactor_style = istyle_class()
 
         istyle = rwi.interactor_style
-        istyle.add_observer("LeftButtonPressEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("LeftButtonReleaseEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("MiddleButtonPressEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("MiddleButtonReleaseEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("RightButtonPressEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("RightButtonReleaseEvent", self._vtk_mouse_button_event)
-        istyle.add_observer("MouseMoveEvent", self._vtk_mouse_move)
-        istyle.add_observer("MouseWheelForwardEvent", self._vtk_mouse_wheel)
-        istyle.add_observer("MouseWheelBackwardEvent", self._vtk_mouse_wheel)
+        self._add_observer(istyle, "LeftButtonPressEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "LeftButtonReleaseEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "MiddleButtonPressEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "MiddleButtonReleaseEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "RightButtonPressEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "RightButtonReleaseEvent", self._vtk_mouse_button_event)
+        self._add_observer(istyle, "MouseMoveEvent", self._vtk_mouse_move)
+        self._add_observer(istyle, "MouseWheelForwardEvent", self._vtk_mouse_wheel)
+        self._add_observer(istyle, "MouseWheelBackwardEvent", self._vtk_mouse_wheel)
 
-        istyle.add_observer("KeyPressEvent", self._vtk_key_updown)
+        self._add_observer(istyle, "KeyPressEvent", self._vtk_key_updown)
 
-        istyle.add_observer("TimerEvent", self._vtk_timer_event)
-        istyle.add_observer("RenderEvent", self._vtk_render_event)
-        istyle.add_observer("ExposeEvent", self._vtk_expose_event)
+        self._add_observer(istyle, "TimerEvent", self._vtk_timer_event)
+        self._add_observer(istyle, "RenderEvent", self._vtk_render_event)
+        self._add_observer(istyle, "ExposeEvent", self._vtk_expose_event)
         self.interactor_style = istyle
 
         self._redraw_timer = rwi.create_repeating_timer(16)
@@ -126,7 +137,7 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
 
         self._mapper = tvtk.ImageMapper()
         self._mapper.color_window = 255
-        self._mapper.color_level = 128
+        self._mapper.color_level = 255/2.0
         self._actor2d.mapper = self._mapper
 
         #self._size = tuple(self._get_control_size())
@@ -140,22 +151,34 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
         #if self.component is not None:
         #    self._paint()
 
+    def _add_observer(self, obj, event, cb):
+        """ Adds a vtk observer using messenger to avoid generating uncollectable objects. """
+        obj.add_observer(event, messenger.send)
+        messenger.connect(tvtk.to_vtk(obj), event, cb)
+
     def _vtk_render_event(self, vtk_obj, eventname):
-        print "Good gods!  A VTK RenderEvent!"
+        #print "Good gods!  A VTK RenderEvent!"
+        pass
 
     def _vtk_expose_event(self, vtk_obj, eventname):
-        print "Good gods!  A VTK ExposeEvent!"
+        #print "Good gods!  A VTK ExposeEvent!"
+        pass
 
     def _vtk_timer_event(self, vtk_obj, eventname):
         # TODO: how do I check a redraw timer??
         #if self.control._timer_id == self._redraw_timer:
         if 1:
-            # Check for bounds updates
-            if self._size != self._get_control_size():
-                self._layout_needed = True
-            if self._redraw_needed or self._layout_needed:
-                self._paint()
-            self.control.reset_timer(self._redraw_timer)
+            if self.control.timer_event_id == self._redraw_timer:
+                # Hack for spectrum.py demo
+                if getattr(self.component, "timer_callback", None):
+                    self.component.timer_callback()
+
+                # Check for bounds updates
+                if self._size != self._get_control_size():
+                    self._layout_needed = True
+                if self._redraw_needed or self._layout_needed:
+                    self._paint()
+                self.control.reset_timer(self._redraw_timer)
 
     def _pass_event_to_vtk(self, vtk_obj, eventname):
         """ Method to dispatch a particular event name to the appropriate
@@ -189,7 +212,7 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
         if meth is not None:
             meth()
         else:
-            print "Unable to pass through mouse event '%s' to vtkInteractionStyle" % eventname
+            warnings.warn("Unable to pass through mouse event '%s' to vtkInteractionStyle" % eventname)
         return
 
     def _vtk_mouse_button_event(self, vtk_obj, eventname):
@@ -209,7 +232,7 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
             button = "middle"
         else:
             # Unable to figure out the appropriate method to dispatch to
-            print "Unable to create event for", eventname
+            warnings.warn("Unable to create event for", eventname)
             return
 
         if "Press" in eventname:
@@ -220,17 +243,21 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
             setattr(self, "_%s_down"%button, False)
         else:
             # Unable to figure out the appropriate method to dispatch to
-            print "Unable to create event for", eventname
+            warnings.warn("Unable to create event for", eventname)
             return
         event_name = button + "_" + action
-        self._handle_mouse_event(event_name, action)
+        handled = self._handle_mouse_event(event_name, action)
+        if self.event_passthrough and not handled:
+            self._pass_event_to_vtk(vtk_obj, eventname)
 
     def _vtk_mouse_move(self, vtk_obj, eventname):
         x, y = self.control.event_position
         if not (self.x <= x <= self.x2 and self.y <= y <= self.y2):
             return self._pass_event_to_vtk(vtk_obj, eventname)
 
-        self._handle_mouse_event("mouse_move", "move")
+        handled = self._handle_mouse_event("mouse_move", "move")
+        if self.event_passthrough and not handled:
+            self._pass_event_to_vtk(vtk_obj, eventname)
 
     def _vtk_mouse_wheel(self, vtk_obj, eventname):
         x, y = self.control.event_position
@@ -241,10 +268,13 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
             self._wheel_amount = 1
         else:
             self._wheel_amount = -1
-        self._handle_mouse_event("mouse_wheel", "wheel")
+        handled = self._handle_mouse_event("mouse_wheel", "wheel")
+        if self.event_passthrough and not handled:
+            self._pass_event_to_vtk(vtk_obj, eventname)
 
     def _vtk_key_updown(self, vtk_obj, eventname):
-        print "key updown:", self.control.key_sym
+        #print "key updown:", self.control.key_sym
+        pass
 
     def _create_mouse_event(self, event_string):
         """ Returns an enable.MouseEvent that reflects the VTK mouse event.
@@ -291,9 +321,10 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
     def _redraw(self, coordinates=None):
         " Called by the contained component to request a redraw " 
         self._redraw_needed = True
+        if self._actor2d is not None:
+            self._paint()
 
     def _on_size(self):
-        print "on size:"
         pass
 
     def _layout(self, size):
@@ -319,8 +350,18 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
                 self.bounds[1] = new_height
         
         comp = self.component
-        self.component.outer_bounds = self.bounds[:]
-        self.component.do_layout(force=True)
+        dx, dy = size
+        if getattr(comp, "fit_window", False):
+            comp.outer_position = [0,0]
+            comp.outer_bounds = [dx, dy]
+        elif hasattr(comp, "resizable"):
+            if "h" in comp.resizable:
+                comp.outer_x = 0
+                comp.outer_width = dx
+            if "v" in comp.resizable:
+                comp.outer_y = 0
+                comp.outer_height = dy
+        comp.do_layout(force=True)
         
         # Invalidate the GC and the draw flag
         self._gc = None
@@ -366,7 +407,8 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
 
     def _paint(self, event=None):
         
-        size = self._get_control_size()
+        control_size = self._get_control_size()
+        size = list(control_size)
         if self._layout_needed or (size != self._size):
             self._layout(size)
 
@@ -391,14 +433,18 @@ class EnableVTKWindow(AbstractWindow, CoordinateBox):
         try:
             ary = ascontiguousarray(self._gc.bmp_array[::-1, :, :4])
             ary_2d = reshape(ary, (width * height, 4))
-        except:
-            import pdb; pdb.set_trace()
+        except Exception, e:
+            warnings.warn("Error reshaping array of shape %s to width and height of (%d, %d)" % (str(ary.shape), width, height))
+            return
 
         # Make sure we paint to the right location on the mapper
         self._vtk_image_data.point_data.scalars = ary_2d
         self._vtk_image_data.modified()
         #self._window_paint(event)
-        self.control.render()
+        if self.request_render is not None:
+            self.request_render()
+        else:
+            self.control.render()
         self._redraw_needed = False
 
 
