@@ -26,6 +26,7 @@
 
 #include "agg_scanline_u.h"
 #include "agg_scanline_bin.h"
+#include "agg_scanline_p.h"
 
 #include "agg_renderer_mclip.h"
 #include "agg_renderer_scanline.h"
@@ -456,7 +457,8 @@ namespace kiva
         void linear_gradient(double x1, double y1,
                             double x2, double y2,
                             std::vector<kiva::gradient_stop> stops,
-                            const char* spread_method)
+                            const char* spread_method,
+                            const char* units="userSpaceOnUse")
         {
             typedef std::pair<double, double> point_type;
             std::vector<gradient_stop> stops_list;
@@ -465,13 +467,16 @@ namespace kiva
             points.push_back(point_type(x1, y1));
             points.push_back(point_type(x2, y2));
 
-            this->state.gradient_fill = gradient(kiva::grad_linear, points, stops, spread_method);
+            this->state.gradient_fill = gradient(kiva::grad_linear, points,
+												stops, spread_method, units);
+            this->state.gradient_fill.set_ctm(this->get_ctm());
         }
 
         void radial_gradient(double cx, double cy, double r,
                             double fx, double fy,
                             std::vector<kiva::gradient_stop> stops,
-                            const char* spread_method)
+                            const char* spread_method,
+                            const char* units="userSpaceOnUse")
         {
             typedef std::pair<double, double> point_type;
             std::vector<point_type> points;
@@ -480,7 +485,9 @@ namespace kiva
             points.push_back(point_type(r, 0));
             points.push_back(point_type(fx, fy));
 
-            this->state.gradient_fill = gradient(kiva::grad_radial, points, stops, spread_method);
+            this->state.gradient_fill = gradient(kiva::grad_radial, points,
+												stops, spread_method, units);
+            this->state.gradient_fill.set_ctm(this->get_ctm());
         }
 
 
@@ -732,7 +739,8 @@ namespace kiva
         }
         else
         {
-            throw clipping_path_unsupported;
+        	this->renderer.reset_clipping(true);
+        	this->state.clipping_path = this->path;
         }
     }
 
@@ -743,7 +751,20 @@ namespace kiva
     template <class agg_pixfmt>
     void graphics_context<agg_pixfmt>::clip()
     {
-        throw kiva::not_implemented_error;
+//    	this->state.clipping_path = this->path;
+
+        agg::scanline_p8 scanline;
+
+        agg::renderer_scanline_aa_solid< renderer_base_type >
+                    aa_renderer(this->renderer);
+
+        agg::rgba transparent = this->state.fill_color;
+        transparent.a = 0;
+
+        aa_renderer.color(transparent);
+
+        this->stroke_path_scanline_aa(this->state.clipping_path,
+                                      aa_renderer, scanline);
     }
 
     template <class agg_pixfmt>
