@@ -117,14 +117,14 @@ namespace agg
     pix_format_e format = get_pix_format();
     rgba8 c;
     unsigned i,j;
-    int dims[3];
+    npy_intp dims[3];
     PyObject* arr = NULL;
     char* data = NULL;
     dims[0] = w;
     dims[1] = h;
     dims[2] = 3;
     import_array();
-    arr = PyArray_FromDims(3,dims,PyArray_CHAR);
+    arr = PyArray_SimpleNew(3,dims,PyArray_BYTE);
     if (arr==NULL)
       return NULL;
     data = ((PyArrayObject *)arr)->data;
