@@ -44,7 +44,7 @@ class CompiledPath(kiva.CompiledPath):
 
     def elliptical_arc_to(self, rx, ry, phi, large_arc_flag, sweep_flag, x2, y2):
         if sys.platform == 'darwin':
-            x1, y1 = path.get_current_point()
+            x1, y1 = self.get_current_point()
         else:
             def _get_current_point(path):
                 total_vertices = path.total_vertices()
@@ -69,6 +69,44 @@ class CompiledPath(kiva.CompiledPath):
             if i == 0:
                 self.move_to(x1,y1)
             self.curve_to(x2,y2, x3,y3, x4,y4)
+            
+    def AddRoundedRectangleEx(self, x, y, w, h, rx, ry):
+        #origin
+        self.move_to(x+rx, y)
+        self.line_to(x+w-rx, y)
+        #top right
+        cx = rx * 2
+        cy = ry * 2
+        self.AddEllipticalArcTo(
+            x+w-cx, y,
+            cx, cy,
+            270, 90,
+        )
+        self.AddLineToPoint(x+w, y+h-ry)
+        #top left
+        self.AddEllipticalArcTo(
+            x+w-cx, y+h-cy,
+            cx, cy,
+            0, 90,
+        )
+        self.line_to(x+rx, y+h)
+        #bottom left
+        self.AddEllipticalArcTo(
+            x, y+h-cy,
+            cx, cy,
+            90,
+            90,
+        )
+        self.line_to(x, y+ry)
+        #bottom right
+        self.AddEllipticalArcTo(
+            x, y,
+            cx, cy,
+            180,
+            90,
+        )
+        self.close_path()
+        
 
 
 Canvas = kiva.Canvas
@@ -130,14 +168,17 @@ class ColorBrush(object):
         """ Set the appropriate properties on the GraphicsContext.
         """
         # translate from 0-255 to 0-1 values.
-        color = tuple([x/255.0 for x in self.color])
+        try:
+            color = tuple([x/255.0 for x in list(self.color)])
+        except:
+            color = (0,0,0,1)
         gc.set_fill_color(color)
 
 class LinearGradientBrush(AbstractGradientBrush):
     """ A Brush representing a linear gradient.
     """
     def __init__(self, x1,y1, x2,y2, stops, spreadMethod='pad',
-        transforms=None, units='userSpaceOnUse'):
+        transforms=[], units='userSpaceOnUse'):
         self.x1 = x1
         self.y1 = y1
         self.x2 = x2
@@ -146,20 +187,22 @@ class LinearGradientBrush(AbstractGradientBrush):
         self.spreadMethod = spreadMethod
         self.transforms = transforms
         self.units = units
-
+        
     def __repr__(self):
         return ('LinearGradientBrush(%r,%r, %r,%r, %r, spreadMethod=%r, '
             'transforms=%r, units=%r)' % (self.x1,self.y1, self.x2,self.y2, self.stops,
                 self.spreadMethod, self.transforms, self.units))
 
     def set_on_gc(self, gc, bbox=None):
-
+        
         # Apply transforms
         if self.transforms is not None:
-            for func, args in self.transforms:
-                func(gc, *args)
-                
-
+            for func, f_args in self.transforms:
+                if isinstance(f_args, tuple):
+                    func(gc, *f_args)
+                else:
+                    func(gc, f_args)
+                    
         x1 = self.x1
         x2 = self.x2
         y1 = self.y1
@@ -179,22 +222,17 @@ class LinearGradientBrush(AbstractGradientBrush):
                 x2 = (bbox[2] + bbox[0])*x2
                 y2 = (bbox[3] + bbox[1])*y2
                 
-            # kiva and SVGs have different origins, so flip the points
-            y1 = gc.height() - y1
-            y2 = gc.height() - y2
-
-        if self.units == 'objectBoundingBox' and bbox is not None:
-            self.bbox_transform(gc, bbox)
-                
+                self.bbox_transform(gc, bbox)
+            
         stops = np.transpose(self.stops)
-        gc.linear_gradient(x1, y1, x2, y2, stops, self.spreadMethod)            
+        gc.linear_gradient(x1, y1, x2, y2, stops, self.spreadMethod, self.units)            
 
 
 class RadialGradientBrush(AbstractGradientBrush):
     """ A Brush representing a radial gradient.
     """
     def __init__(self, cx,cy, r, stops, fx=None,fy=None, spreadMethod='pad',
-        transforms=None, units='userSpaceOnUse'):
+        transforms=[], units='userSpaceOnUse'):
         self.cx = cx
         self.cy = cy
         self.r = r
@@ -218,8 +256,11 @@ class RadialGradientBrush(AbstractGradientBrush):
     def set_on_gc(self, gc, bbox=None):
         
         if self.transforms is not None:
-            for func, args in self.transforms:
-                func(gc, *args)
+            for func, f_args in self.transforms:
+                if isinstance(f_args, tuple):
+                    func(gc, *f_args)
+                else:
+                    func(gc, f_args)
 
         cx = self.cx
         cy = self.cy
@@ -242,18 +283,10 @@ class RadialGradientBrush(AbstractGradientBrush):
                 fy = (bbox[3] + bbox[1])*fy
                 r *= np.sqrt((bbox[2] - bbox[0])**2 + (bbox[3] - bbox[1])**2)
 
-            # kiva and SVGs have different origins, so flip the points
-            cy = gc.height()-cy
-            fy = gc.height()-fy
+                self.bbox_transform(gc, bbox)
 
-        if self.units == 'objectBoundingBox' and bbox is not None:
-            self.bbox_transform(gc, bbox)
-
-            pass
-
-                            
         stops = np.transpose(self.stops)
-        gc.radial_gradient(cx, cy, r, fx, fy, stops, self.spreadMethod)
+        gc.radial_gradient(cx, cy, r, fx, fy, stops, self.spreadMethod, self.units)
 
 
 def font_style(font):
@@ -329,13 +362,13 @@ class Renderer(NullRenderer):
 
     @classmethod
     def createLinearGradientBrush(cls, x1,y1,x2,y2, stops, spreadMethod='pad',
-                                  transforms=None, units='userSpaceOnUse'):
+                                  transforms=[], units='userSpaceOnUse'):
         return LinearGradientBrush(x1,y1,x2,y2,stops, spreadMethod, transforms,
             units)
 
     @classmethod
     def createRadialGradientBrush(cls, cx,cy, r, stops, fx=None,fy=None,
-                                  spreadMethod='pad', transforms=None,
+                                  spreadMethod='pad', transforms=[],
                                   units='userSpaceOnUse'):
         return RadialGradientBrush(cx,cy, r, stops, fx,fy, spreadMethod,
             transforms, units)
@@ -456,7 +489,8 @@ class Renderer(NullRenderer):
     def gradientPath(cls, gc, path, brush):
         gc.save_state()
         gc.add_path(path)
-        #gc.clip()
+        
+        gc.clip()
         if hasattr(path, 'get_bounding_box'):
             bbox = path.get_bounding_box()
         else:
@@ -469,15 +503,15 @@ class Renderer(NullRenderer):
                 bbox[3] = max(bbox[3], vertex[0][1])
 
         brush.set_on_gc(gc, bbox=bbox)
+        
+        gc.close_path()
         gc.fill_path()
         gc.restore_state()
 
-    #@classmethod
-    #def clipPath(cls, gc, path):
-        #print "clipping!"
-        #return gc.clip_to_rect(100, 10, 100, 60)
-        ##gc.add_path(path)
-        ##return gc.clip()
+    @classmethod
+    def clipPath(cls, gc, path):
+        gc.add_path(path)
+        return gc.clip()
 
     @classmethod
     def translate(cls, gc, *args):
