@@ -1,9 +1,18 @@
+import copy
 import numpy
 import warnings
 import wx
 
 from enthought.savage.svg.backends.null.null_renderer import NullRenderer
 
+
+def _fixup_path_methods(path):
+    def _new_add_rounded_rectangle(self, x, y, w, h, rx, ry):
+        r = numpy.sqrt(rx*rx + ry*ry)
+        self.AddRoundedRectangle(x, y, w, h, r)
+
+    path.__class__.AddRoundedRectangleEx = _new_add_rounded_rectangle
+
 class AbstractGradientBrush(object):
     """ Abstract base class for gradient brushes so they can be detected easily.
     """
@@ -16,7 +25,7 @@ class AbstractGradientBrush(object):
         """
         x0, y0, w, h = bbox
         gc.concat_ctm(((w, 0, 0), (0, h, 0), (x0, y0, 1)))
-
+        
 class Renderer(NullRenderer):
 
     NullBrush = wx.NullBrush
@@ -92,23 +101,21 @@ class Renderer(NullRenderer):
         if len(stops) > 2:
             warnings.warn("Wx only supports 2 gradient stops, but %d were specified" % len(stops))
 
-
-
         def convert_stop(stop):
             offset, red, green, blue, opacity = stop
             color = wx.Colour(red*255, green*255, blue*255, opacity*255)
             return offset, color
 
         start_offset, start_color = convert_stop(stops[0])
-        end_offset, end_color = convert_stop(stops[1])
+        end_offset, end_color = convert_stop(stops[-1])
 
         if fx is None:
             fx = cx
         if fy is None:
             fy = cy
-
+			
         wx_renderer = wx.GraphicsRenderer.GetDefaultRenderer()
-        return wx_renderer.CreateRadialGradientBrush(cx, cy, fx, fy, r,
+        return wx_renderer.CreateRadialGradientBrush(fx, fy, cx, cy, r,
                                                      start_color, end_color)
 
     @staticmethod
@@ -129,7 +136,9 @@ class Renderer(NullRenderer):
 
     @staticmethod
     def makePath():
-        return wx.GraphicsRenderer_GetDefaultRenderer().CreatePath()
+        path = wx.GraphicsRenderer_GetDefaultRenderer().CreatePath()
+        _fixup_path_methods(path)
+        return path
 
     @staticmethod
     def popState(*args):
@@ -201,6 +210,13 @@ class Renderer(NullRenderer):
         #rather than the top as with our API. This function
         #will measure and then re-orient the text as needed.
         w, h = context.GetTextExtent(text)
+        
+        if anchor != 'start':
+            if anchor == 'middle':
+                x -= w/2.0
+            elif anchor == 'end':
+                x -= w
+        
         y -= h
         context.DrawText(text, x, y)
 
