@@ -256,6 +256,17 @@ class SVGDocument(object):
         self.clippingStack = []
         path, ops = self.processElement(element)
         self.ops = ops
+        
+    @classmethod
+    def createFromFile(cls, filename, renderer):
+        if not os.path.exists(filename):
+            raise IOError('No such file: ' + filename)
+        
+        tree = ET.parse(filename)
+        root = tree.getroot()
+        
+        resources = ResourceGetter(os.path.dirname(filename))
+        return cls(root, resources, renderer)
 
 
     def getSize(self):
@@ -263,13 +274,13 @@ class SVGDocument(object):
         width_node = self.tree.get('width')
         if width_node is not None:
             # omit 'px' if it was specified
-            width=int(width_node.split('px')[0])
+            width=int(float(width_node.split('px')[0]))
 
         height = -1
         height_node = self.tree.get('height')
         if height_node is not None:
             # omit 'px' if it was specified
-            height=int(height_node.split('px')[0])
+            height=int(float(height_node.split('px')[0]))
 
         return (width, height)
 
@@ -625,7 +636,7 @@ class SVGDocument(object):
         ry = node.get('ry')
 
         ops = []
-
+        
         if 'clip-path' in node.keys():
             element = self.dereference(node.get('clip-path'))
 
@@ -661,42 +672,8 @@ class SVGDocument(object):
             #value clamping as per spec section 9.2
             rx = min(rx, w/2)
             ry = min(ry, h/2)
-
-            #origin
-            path.MoveToPoint(x+rx, y)
-            path.AddLineToPoint(x+w-rx, y)
-            #top right
-            cx = rx * 2
-            cy = ry * 2
-            path.AddEllipticalArcTo(
-                x+w-cx, y,
-                cx, cy,
-                270, 90,
-            )
-            path.AddLineToPoint(x+w, y+h-ry)
-            #top left
-            path.AddEllipticalArcTo(
-                x+w-cx, y+h-cy,
-                cx, cy,
-                0, 90,
-            )
-            path.AddLineToPoint(x+rx, y+h)
-            #bottom left
-            path.AddEllipticalArcTo(
-                x, y+h-cy,
-                cx, cy,
-                90,
-                90,
-            )
-            path.AddLineToPoint(x, y+ry)
-            #bottom right
-            path.AddEllipticalArcTo(
-                x, y,
-                cx, cy,
-                180,
-                90,
-            )
-            path.CloseSubpath()
+            
+            path.AddRoundedRectangleEx(x, y, w, h, rx, ry)
         else:
             if len(self.clippingStack) > 0:
                 self.renderer.clipPath()
@@ -928,7 +905,7 @@ class SVGDocument(object):
                 transforms = self.createTransformOpsFromNode(state,
                     'gradientTransform')
                 if not transforms:
-                    transforms = None
+                    transforms = []
                 units = state.get('gradientUnits', 'objectBoundingBox')
                 stops = self.parseStops(element)
                 if stops.size == 0:
