@@ -25,7 +25,6 @@ import os.path
 import wx
 
 # ETS imports
-from enthought.pyface.widget import Widget
 from enthought.savage.svg.document import SVGDocument
 from enthought.savage.svg.backends.wx.renderer import Renderer
 from enthought.traits.api import Instance
@@ -76,11 +75,11 @@ class ButtonRenderPanel(RenderPanel):
         dc.SetBackground(wx.Brush(self.GetBackgroundColour()))
         dc.Clear()
         dc.SetFont(wx.SystemSettings.GetFont(wx.SYS_DEFAULT_GUI_FONT))
-        text_width = dc.GetTextExtent(self.button.factory.label)[0]
 
         gc = wx.GraphicsContext_Create(dc)
 
-        if self.toggle_state and self.button.factory.toggle:
+        if self.toggle_state and self.button.factory.toggle and \
+                not self.button.factory.toggle_filename:
             self._draw_toggle(gc)
 
         # Put the icon in the middle of the alotted space. If the text is wider
@@ -94,7 +93,13 @@ class ButtonRenderPanel(RenderPanel):
         gc.Translate(x_offset, y_offset)
         gc.Scale(float(self.zoom_x) / 100, float(self.zoom_y) / 100)
 
-        self.document.render(gc)
+        if self.toggle_state and self.button.factory.toggle and \
+                self.button.factory.toggle_filename:
+            self.toggle_document.render(gc)
+            label_text = self.button.factory.toggle_label
+        else:
+            self.document.render(gc)
+            label_text = self.button.factory.label
 
         # Reset the translation and zoom, then draw the text at an offset
         # based on the text width. There is a minor gotcha for supporting
@@ -102,24 +107,33 @@ class ButtonRenderPanel(RenderPanel):
         # on different platforms. 
         # It would be nice is a cross platform library actually worked the
         # same across platforms...
-
+        
+        text_width = dc.GetTextExtent(label_text)[0]
         text_x = (best_size.width - text_width)/2.0
         text_y = self.button.factory.height
         gc.Scale(100/float(self.zoom_x), 100/float(self.zoom_y))
         
         if sys.platform == 'darwin':
             gc.Translate(-x_offset + text_x, -y_offset + text_y)
-            dc.DrawText(self.button.factory.label, 0, 0)
+            dc.DrawText(label_text, 0, 0)
         else:
             gc.Translate(-x_offset, -y_offset)
-            dc.DrawText(self.button.factory.label, text_x, text_y)
+            dc.DrawText(label_text, text_x, text_y)
             
+        if not self.button.enabled:
+            self._draw_disable_mask(gc)
 
     def OnLeftDown(self, evt):
         # if the button is supposed to toggle, set the toggle_state
         # to the opposite of what it currently is
         if self.button.factory.toggle:
             self.toggle_state = not self.toggle_state
+            
+            if self.toggle_state:
+                tooltip = wx.ToolTip(self.button.factory.toggle_tooltip)
+            else:
+                tooltip = wx.ToolTip(self.button.factory.tooltip)
+            self.button.control.SetToolTip(tooltip)
 
         self.state = 'down'
         evt.Skip()
@@ -142,6 +156,19 @@ class ButtonRenderPanel(RenderPanel):
     def OnWheel(self, evt):
         pass
 
+    def _draw_disable_mask(self, gc):
+        """ Draws a mask using the background color with the alpha
+            set to about 33%
+        """
+        best_size = self.DoGetBestSize()
+
+        path = gc.CreatePath()
+        path.AddRectangle(0, 0, best_size.width, best_size.height)
+        bgcolor = self.GetBackgroundColour()
+        bgcolor.Set(bgcolor.red, bgcolor.green, bgcolor.blue, 175)
+        gc.SetBrush(wx.Brush(bgcolor))
+        gc.FillPath(path)
+
     def _draw_toggle(self, gc):
         # the toggle doc and button doc may not be the same
         # size, so calculate the scaling factor. Byt using the padding
@@ -186,14 +213,16 @@ class SVGButtonEditor ( Editor ):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
-
-        tree = etree.parse(self.factory.filename)
-        self.document = SVGDocument(tree.getroot(), renderer=Renderer)
+        
+        self.document = SVGDocument.createFromFile(self.factory.filename, renderer=Renderer)
 
         # load the button toggle document which will be displayed when the
         # button is toggled.
-        tree = etree.parse(os.path.join(os.path.dirname(__file__), 'data', 'button_toggle.svg'))
-        self.toggle_document = SVGDocument(tree.getroot(), renderer=Renderer)
+        if self.factory.toggle_filename:
+            self.toggle_document = SVGDocument.createFromFile(self.factory.toggle_filename, renderer=Renderer)
+        else:
+            tree = etree.parse(os.path.join(os.path.dirname(__file__), 'data', 'button_toggle.svg'))
+            self.toggle_document = SVGDocument(tree.getroot(), renderer=Renderer)
 
         padding = (self.factory.width_padding, self.factory.height_padding)
         self.control = ButtonRenderPanel( parent, self, padding=padding )
